==> evolution-data-server-3.18.3-1-aarch64.pkg.tar.xz: usr/include/evolution-data-server/libedataserver/e-source-enumtypes.h <==

/* Generated data (by glib-mkenums) */

#ifndef E_SOURCE_ENUMTYPES_H
#define E_SOURCE_ENUMTYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "./e-source-enums.h" */

#define E_TYPE_MDN_RESPONSE_POLICY	(e_mdn_response_policy_get_type())
GType e_mdn_response_policy_get_type	(void) G_GNUC_CONST;

#define E_TYPE_PROXY_METHOD	(e_proxy_method_get_type())
GType e_proxy_method_get_type	(void) G_GNUC_CONST;

#define E_TYPE_SOURCE_AUTHENTICATION_RESULT	(e_source_authentication_result_get_type())
GType e_source_authentication_result_get_type	(void) G_GNUC_CONST;

#define E_TYPE_TRUST_PROMPT_RESPONSE	(e_trust_prompt_response_get_type())
GType e_trust_prompt_response_get_type	(void) G_GNUC_CONST;

#define E_TYPE_SOURCE_CONNECTION_STATUS	(e_source_connection_status_get_type())
GType e_source_connection_status_get_type	(void) G_GNUC_CONST;

#define E_TYPE_SOURCE_CREDENTIALS_REASON	(e_source_credentials_reason_get_type())
GType e_source_credentials_reason_get_type	(void) G_GNUC_CONST;

#define E_TYPE_SOURCE_LDAP_AUTHENTICATION	(e_source_ldap_authentication_get_type())
GType e_source_ldap_authentication_get_type	(void) G_GNUC_CONST;

#define E_TYPE_SOURCE_LDAP_SCOPE	(e_source_ldap_scope_get_type())
GType e_source_ldap_scope_get_type	(void) G_GNUC_CONST;

#define E_TYPE_SOURCE_LDAP_SECURITY	(e_source_ldap_security_get_type())
GType e_source_ldap_security_get_type	(void) G_GNUC_CONST;

#define E_TYPE_SOURCE_WEATHER_UNITS	(e_source_weather_units_get_type())
GType e_source_weather_units_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_SOURCE_ENUMTYPES_H */

/* Generated data ends here */

==> evolution-data-server-3.24.2-1-aarch64.pkg.tar.xz: usr/include/evolution-data-server/libedataserver/e-source-enumtypes.h <==

/* Generated data (by glib-mkenums) */

#ifndef E_SOURCE_ENUMTYPES_H
#define E_SOURCE_ENUMTYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "/build/evolution-data-server/src/evolution-data-server/src/libedataserver/e-source-enums.h" */

#define E_TYPE_MDN_RESPONSE_POLICY	(e_mdn_response_policy_get_type())
GType e_mdn_response_policy_get_type	(void) G_GNUC_CONST;

#define E_TYPE_PROXY_METHOD	(e_proxy_method_get_type())
GType e_proxy_method_get_type	(void) G_GNUC_CONST;

#define E_TYPE_SOURCE_AUTHENTICATION_RESULT	(e_source_authentication_result_get_type())
GType e_source_authentication_result_get_type	(void) G_GNUC_CONST;

#define E_TYPE_TRUST_PROMPT_RESPONSE	(e_trust_prompt_response_get_type())
GType e_trust_prompt_response_get_type	(void) G_GNUC_CONST;

#define E_TYPE_SOURCE_CONNECTION_STATUS	(e_source_connection_status_get_type())
GType e_source_connection_status_get_type	(void) G_GNUC_CONST;

#define E_TYPE_SOURCE_CREDENTIALS_REASON	(e_source_credentials_reason_get_type())
GType e_source_credentials_reason_get_type	(void) G_GNUC_CONST;

#define E_TYPE_SOURCE_LDAP_AUTHENTICATION	(e_source_ldap_authentication_get_type())
GType e_source_ldap_authentication_get_type	(void) G_GNUC_CONST;

#define E_TYPE_SOURCE_LDAP_SCOPE	(e_source_ldap_scope_get_type())
GType e_source_ldap_scope_get_type	(void) G_GNUC_CONST;

#define E_TYPE_SOURCE_LDAP_SECURITY	(e_source_ldap_security_get_type())
GType e_source_ldap_security_get_type	(void) G_GNUC_CONST;

#define E_TYPE_SOURCE_WEATHER_UNITS	(e_source_weather_units_get_type())
GType e_source_weather_units_get_type	(void) G_GNUC_CONST;

#define E_TYPE_SOURCE_MAIL_COMPOSITION_REPLY_STYLE	(e_source_mail_composition_reply_style_get_type())
GType e_source_mail_composition_reply_style_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_SOURCE_ENUMTYPES_H */

/* Generated data ends here */
